#
# spec file for package ghc-http-conduit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name http-conduit
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.3.9.1
Release:        bp160.1.9
Summary:        HTTP client package with conduit interface and HTTPS support
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-attoparsec-aeson-devel
BuildRequires:  ghc-attoparsec-aeson-prof
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-attoparsec-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-conduit-extra-devel
BuildRequires:  ghc-conduit-extra-prof
BuildRequires:  ghc-conduit-prof
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-http-client-prof
BuildRequires:  ghc-http-client-tls-devel
BuildRequires:  ghc-http-client-tls-prof
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-http-types-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-resourcet-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unliftio-core-devel
BuildRequires:  ghc-unliftio-core-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-blaze-builder-prof
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-case-insensitive-prof
BuildRequires:  ghc-cookie-devel
BuildRequires:  ghc-cookie-prof
BuildRequires:  ghc-crypton-connection-devel
BuildRequires:  ghc-crypton-connection-prof
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-data-default-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-prof
BuildRequires:  ghc-streaming-commons-devel
BuildRequires:  ghc-streaming-commons-prof
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-temporary-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-tls-devel
BuildRequires:  ghc-tls-prof
BuildRequires:  ghc-unliftio-devel
BuildRequires:  ghc-unliftio-prof
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  ghc-utf8-string-prof
BuildRequires:  ghc-wai-conduit-devel
BuildRequires:  ghc-wai-conduit-prof
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-wai-prof
BuildRequires:  ghc-warp-devel
BuildRequires:  ghc-warp-prof
BuildRequires:  ghc-warp-tls-devel
BuildRequires:  ghc-warp-tls-prof
%endif

%description
Hackage documentation generation is not reliable. For up to date documentation,
please see: <http://www.stackage.org/package/http-conduit>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Oct 27 2024 Peter Simons <psimons@suse.com>
- Update http-conduit to version 2.3.9.1.
  [#]# 2.3.9.1
  * data-default-class -> data-default [#546](https://github.com/snoyberg/http-client/pull/546/files)
* Mon Aug 26 2024 Peter Simons <psimons@suse.com>
- Update http-conduit to version 2.3.9.
  [#]# 2.3.9
  * Fix space leaks when closing responses [#539](https://github.com/snoyberg/http-client/pull/539)
* Fri May  3 2024 Peter Simons <psimons@suse.com>
- Forgot to update copyright header in spec file after last change.
* Tue Mar 12 2024 Peter Simons <psimons@suse.com>
- Drop obsolete 'drop-dependency-on-empty-attoparsec-aeson-library.patch'.
* Thu Nov 16 2023 Peter Simons <psimons@suse.com>
- Update http-conduit to version 2.3.8.3.
  * aeson 2.2 support [#512](https://github.com/snoyberg/http-client/pull/512)
- Apply drop-dependency-on-empty-attoparsec-aeson-library.patch to
  fix the build.
* Mon Jul 17 2023 Peter Simons <psimons@suse.com>
- Update http-conduit to version 2.3.8.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Jun  9 2023 Peter Simons <psimons@suse.com>
- Update http-conduit to version 2.3.8.2.
  [#]# 2.3.8.2
  * Add missing `crypton-connection` dependency
  [#]# 2.3.8.1
  * Drop `connection` dependency
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Feb 21 2021 psimons@suse.com
- Update http-conduit to version 2.3.8.
  [#]# 2.3.8
  * Adds `setRequestBearerAuth` convenience function. Note that this is only available for `http-client` versions 0.7.6 or greater. [#457](https://github.com/snoyberg/http-client/pull/457/files)
  * Adds a convenience function to set a request's response timeout [#456](https://github.com/snoyberg/http-client/pull/456)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Fri Dec  4 2020 psimons@suse.com
- Update http-conduit to version 2.3.7.4.
  [#]# 2.3.7.4
  * Introduces the `aeson` cabal file [#448](https://github.com/snoyberg/http-client/issues/448)
* Mon Aug 31 2020 psimons@suse.com
- Update http-conduit to version 2.3.7.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Aug 19 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with 6GB min disk space for ppc64/ppc64le
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Thu Oct 10 2019 psimons@suse.com
- Update http-conduit to version 2.3.7.3.
  [#]# 2.3.7.3
  * Relax test suite version bounds
* Tue Oct  8 2019 psimons@suse.com
- Update http-conduit to version 2.3.7.2.
  [#]# 2.3.7.2
  * Add the `network3` flag
* Wed May  1 2019 psimons@suse.com
- Update http-conduit to version 2.3.7.1.
  [#]# 2.3.7.1
  * Properly skip whitespace after JSON body [#401](https://github.com/snoyberg/http-client/issues/401)
* Wed Apr  3 2019 psimons@suse.com
- Update http-conduit to version 2.3.7.
  [#]# 2.3.7
  * Ensure entire JSON response body is consumed [#395](https://github.com/snoyberg/http-client/issues/395)
* Wed Mar 13 2019 psimons@suse.com
- Update http-conduit to version 2.3.6.1.
  [#] ChangeLog for http-conduit
  [#]# 2.3.6.1
  * Add back compatibility with older http-client version [#393](https://github.com/snoyberg/http-client/pull/393)
* Tue Mar 12 2019 psimons@suse.com
- Update http-conduit to version 2.3.6.
  [#]# 2.3.6
  * Add `httpSource` to `Network.HTTP.Client.Conduit` [#390](https://github.com/snoyberg/http-client/pull/390).
* Tue Jan 29 2019 psimons@suse.com
- Update http-conduit to version 2.3.5.
  [#]# 2.3.5
  * Adds `addToRequestQueryString` helper function
* Sat Jan 19 2019 Peter Simons <psimons@suse.com>
- Update Cabal build instructions for more accurate dependencies.
* Mon Nov 26 2018 psimons@suse.com
- Update http-conduit to version 2.3.4.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/http-conduit-2.3.4/src/ChangeLog.md
* Sat Nov 24 2018 psimons@suse.com
- Update http-conduit to version 2.3.3.
  [#]# 2.3.3
  * Reexport Header, QueryItem and RequestHeaders from Network.HTTP.Types
  * Rewrite a type signature of setRequestHeaders with RequestHeaders
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update http-conduit to version 2.3.2.
  [#]# 2.3.2
  * Adds `parseRequestThrow`, `parseRequestThrow_`, and
    `setRequestCheckStatus` to `Network.HTTP.Simple`.
    See [#304](https://github.com/snoyberg/http-client/issues/304)
* Mon May 14 2018 psimons@suse.com
- Update http-conduit to version 2.3.1.
  * Reexport Query from Network.HTTP.Types
  * Rewrite a type signatures of getRequestQueryString and setRequestQueryString with Query
  * conduit 1.3 support
  * NOTE: Even for older versions of conduit, this includes dropping
    support for finalizers
  * `http` returns a `Source` instead of a `ResumableSource` (due to lack of
    finalizers)
  * Drop monad-control for unliftio
  * Removed some deprecated functions: `withManager`, `withManagerSettings`,
    `conduitManagerSettings`
  * Add `httpBS` to `Network.HTTP.Simple`
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jul 17 2017 psimons@suse.com
- Update to version 2.2.3.2.
* Mon Feb 27 2017 psimons@suse.com
- Update to version 2.2.3.1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 2.2.3 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.1.11 revision 0 with cabal2obs.
* Mon Jul  4 2016 mimi.vx@gmail.com
- update to 2.1.11
  * Switch to non-throwing behavior in Network.HTTP.Simple
* Sat May  7 2016 mimi.vx@gmail.com
- update to 2.1.10.1
  * Fix mistaken @since comments
* Sat Apr 16 2016 mimi.vx@gmail.com
- update to 2.1.10
  * Add the Network.HTTP.Simple module
* Tue Apr 12 2016 mimi.vx@gmail.com
- update to 2.1.9
  * cleanup
* Thu Aug 13 2015 mimi.vx@gmail.com
- update to 2.1.8
  * Move HasHttpManager from http-conduit to http-client
* Tue Aug  4 2015 mimi.vx@gmail.com
- update to 2.1.7.2
* Mon Jul 27 2015 mimi.vx@gmail.com
- update to 2.1.7.1
  * Deprecate conduitManagerSettings, re-export tlsManagerSettings
  * Deprecate withManager and withManagerSettings
* Mon Jul  6 2015 mimi.vx@gmail.com
- update to 2.1.5.1
* Tue May 19 2015 mimi.vx@gmail.com
- correct license to BSD-2-Clause
* Tue May  5 2015 mimi.vx@gmail.com
- updated to 2.1.5
- spec regenerated with cabal-rpm
  * no upstream changelog
* Mon Oct  7 2013 sbahling@suse.com
- Initial package - version 1.9.5.1
